#region Using

using System;
using System.Net;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Text;

#endregion

public partial class autodiscovery : System.Web.UI.Page
{
	/// <summary>
	/// Handles the Load event of the Page control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	protected void Page_Load(object sender, EventArgs e)
	{
		btnFind.Click += new EventHandler(btnFind_Click);

		if (!Page.IsPostBack && !string.IsNullOrEmpty(Request.QueryString["url"]))
		{
			cbOutbound.Checked = Request.QueryString["out"] == "True";
			cbInbound.Checked = Request.QueryString["in"] == "True";			

			Uri uri = new Uri(Request.QueryString["url"]);
			SocialGraph graph = new SocialGraph();
			graph.EnableOutboundLinks = cbOutbound.Checked;
			graph.EnableInboundLinks = cbInbound.Checked;	
			graph.Update(uri);

			WriteGraph(graph);
			txtUrl.Text = uri.ToString();
		}
	}

	/// <summary>
	/// Handles the Click event of the btnFind control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	void btnFind_Click(object sender, EventArgs e)
	{
		string url = txtUrl.Text.Trim();
		if (!url.Contains("://"))
			url = "http://" + url;

		string query = "?out=" + cbOutbound.Checked + "&in=" + cbInbound.Checked;
		Response.Redirect(Request.FilePath + query + "&url=" + Server.UrlEncode(url), true);
	}

	/// <summary>
	/// Writes the social graph to the page.
	/// </summary>
	private void WriteGraph(SocialGraph graph)
	{
		StringBuilder sb = new StringBuilder();
		sb.Append("<h2>" + graph.Url + "</h2>");

		sb.Append("<h3>Verified claims</h3>");
		foreach (string profile in graph.VerifiedClaims)
		{
			sb.Append(profile + "<br />");
		}

		sb.Append("<h3>Unverified claims</h3>");
		foreach (string profile in graph.UnverifiedClaims)
		{
			sb.Append(profile + "<br />");
		}

		sb.Append("<h3>Outbound links</h3>");

		foreach (string key in graph.Outbound.Keys)
		{
			string xfn = string.Empty;
			foreach (string tag in graph.Outbound[key])
			{
				xfn += tag + " ";
			}

			sb.Append(key + " (" + xfn + ")<br />");
		}

		sb.Append("<h3>Inbound links</h3>");

		foreach (string key in graph.Inbound.Keys)
		{
			string xfn = string.Empty;
			foreach (string tag in graph.Inbound[key])
			{
				xfn += tag + " ";
			}

			sb.Append(key + " (" + xfn + ")<br />");
		}

		divResult.InnerHtml += sb.ToString();
	}
}
